@@ -71,7 +71,8 @@ function(e1,e2)
 {
     # take intersection of dates
     i.dates <- sort(intersect(dates(e1),dates(e2)))
-    
+    class(i.dates) <- c("POSIXt","POSIXct")
+
     # add the data, taking the subset of the core for which the dates match
     ans <- callGeneric(e1[dates=i.dates,]@.Data,e2[dates=i.dates,]@.Data)
   
@@ -79,6 +80,20 @@ function(e1,e2)
     return(its(ans,i.dates))
 }
 )
+setMethod("Arith",signature("its", "numeric"),
+function(e1,e2)
+{
+    ans <- callGeneric(e1@.Data,e2) 
+    return(its(ans,dates(e1)))
+}
+)
+setMethod("Arith",signature("numeric","its"),
+function(e1,e2)
+{
+    ans <- callGeneric(e1,e2@.Data)  
+    return(its(ans,dates(e2)))
+}
+)
 #plot-method--------------------------------------------------------
 if(!isGeneric("plot")) setGeneric("plot", useAsDefault=plot)
 setMethod("plot",signature(x="its",y="missing"),
